﻿(function () {

    "use strict";

    angular.module("enrMapModule")
           .factory("mapFillColorCalculator", ["$filter", "mapRegionLeaderCalculator", "regionPropertiesParser", "participationCalculator", function ($filter, mapRegionLeaderCalculator, regionPropertiesParser, participationCalculator) {

               return {
                   calculateFillColorOffice: function (regionProperties, electionDataJson, colorData) {
                       var fillColor = "#000000";

                       var regionLeaderResults = mapRegionLeaderCalculator.determineLeader(electionDataJson, regionProperties);

                       switch (regionLeaderResults.scenario) {
                           case mapRegionLeaderCalculator.resultScenarios.distinctLeader:
                               fillColor = $filter("filter")(colorData.PolParty, { POLITICALPARTYID: regionLeaderResults.leaderPartyId.toString() }, true)[0].DISPLAY_COLOR;
                               break;
                           case mapRegionLeaderCalculator.resultScenarios.tie:
                               fillColor = colorData.AdditionalColors.TIE;
                               break;
                           case mapRegionLeaderCalculator.resultScenarios.noResults:
                               fillColor = colorData.AdditionalColors.NO_RESULTS_BUT_PARTICIPATING;
                               break;
                           case mapRegionLeaderCalculator.resultScenarios.notParticipating:
                               fillColor = colorData.AdditionalColors.NOT_PARTICIPATING;
                               break;
                           case mapRegionLeaderCalculator.resultScenarios.multipleLeaders:
                               fillColor = colorData.AdditionalColors.MULTIPLE_LEADERS;
                               break;
                       }
                       return fillColor;
                   },

                   calculateFillColorReferendums: function (regionProperties, electionDataJson, colorData) {
                       var fillColor;

                       var regionIsParticipating = participationCalculator.isReferendumsRegionParticipatingFromSummaryJson(electionDataJson, regionProperties);

                       if (regionIsParticipating) {
                           var regionId = regionPropertiesParser.getRegionPrimaryId(regionProperties, false, true);
                           var regionNodes = $filter("filter")(electionDataJson.Regions.Region, { FIPS: regionId.toString() }, true);
                           var regionNode = regionNodes.length > 0 ? regionNodes[0] : undefined;

                           if (Number(regionNode.Referendums.ALL_POSITIVE_RESULTS) + Number(regionNode.Referendums.ALL_NEGATIVE_RESULTS) === 0)
                               fillColor = colorData.AdditionalColors.NO_RESULTS_BUT_PARTICIPATING;
                           else
                               fillColor = colorData.AdditionalColors.REFERENDUMS;
                       }
                       else 
                           fillColor = colorData.AdditionalColors.NOT_PARTICIPATING;

                       return fillColor;
                   }
               };
           }]);

}());